@@ -402,6 +402,17 @@ class Tio2Jira:
         # start to process our way through the vulnerability iterator.
         for vulnitem in vulns:
             v = flatten(vulnitem)
+
+            # if the tio_ignore_accepted flag is set to True, then will will
+            # ignore the vulnerability, log the ignore, and move on.
+            if (self.config['tenable'].get('tio_ignore_accepted', False)
+              and v.get('severity_modification_type', '').lower() == 'accepted'):
+                self._log.info(
+                    'Skipping {} on {} as it\'s an accepted risk'.format(
+                        v.get('plugin.id'), v.get('asset.uuid')))
+                continue
+
+            # send the vulnerability instance to processing.
             self._process_open_vuln(v, fid)
 
     def close_issues(self, vulns):
